pub struct MarkdownSignature { /* private fields */ }Expand description
A canonical Markdown event stream used for semantic comparison.
Implementations
Sourceimpl MarkdownSignature
impl MarkdownSignature
Sourcepub fn first_divergence(&self, other: &Self) -> Option<String>
pub fn first_divergence(&self, other: &Self) -> Option<String>
Return a short description of the first event divergence.